<?php

namespace App\Mail;

use App\Album;
use App\Facade\Theme;
use App\Photo;
use App\PhotoComment;
use App\User;
use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;

class ModeratePhotoComment extends Mailable
{
    use Queueable, SerializesModels;

    private $album;
    private $comment;
    private $photo;
    private $user;

    /**
     * Create a new message instance.
     *
     * @return void
     */
    public function __construct(User $user, Album $album, Photo $photo, PhotoComment $comment)
    {
        $this->user = $user;
        $this->album = $album;
        $this->photo = $photo;
        $this->comment = $comment;
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        $subject = trans('email.moderate_photo_comment_subject', ['album_name' => $this->album->name]);

        return $this
            ->subject($subject)
            ->markdown(Theme::viewName('email.moderate_photo_comment'))
            ->with([
                'album' => $this->album,
                'comment' => $this->comment,
                'photo'  => $this->photo,
                'subject' => $subject,
                'user' => $this->user
            ]);
    }
}
