<?php

namespace App\Mail;

use App\Facade\Theme;
use App\Facade\UserConfig;
use App\User;
use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;
use Illuminate\Contracts\Queue\ShouldQueue;

class UserChangeEmailRequired extends Mailable
{
    use Queueable, SerializesModels;

    private $user;

    /**
     * Create a new message instance.
     *
     * @return void
     */
    public function __construct(User $user)
    {
        $this->user = $user;
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        $subject = trans('email.change_email_required_subject', ['app_name' => UserConfig::get('app_name')]);

        return $this
            ->subject($subject)
            ->markdown(Theme::viewName('email.user_change_email_required'))
            ->with([
                'subject' => $subject,
                'user' => $this->user
            ]);
    }
}
